==> gemrb-0.4.0.tar.gz: gemrb-0.4.0/gemrb/plugins/Core/ResourceMgr.h <==
/* GemRB - Infinity Engine Emulator
 * Copyright (C) 2003 The GemRB Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $Id: ResourceMgr.h 6005 2009-05-19 10:21:38Z lynxlupodian $
 *
 */

#ifndef RESOURCEMGR_H
#define RESOURCEMGR_H

#include "Plugin.h"
#include "../../includes/SClassID.h"
#include "DataStream.h"
#include "../../includes/globals.h"

#ifdef WIN32

#ifdef GEM_BUILD_DLL
#define GEM_EXPORT __declspec(dllexport)
#else
#define GEM_EXPORT __declspec(dllimport)
#endif

#else
#define GEM_EXPORT
#endif

class GEM_EXPORT ResourceMgr : public Plugin {
public:
	ResourceMgr(void);
	virtual ~ResourceMgr(void);
	virtual bool LoadResFile(const char* resfile) = 0;
	virtual bool HasResource(const char* resname, SClass_ID type, bool silent=false) = 0;
	virtual DataStream* GetResource(const char* resname, SClass_ID type) = 0;
	virtual void* GetFactoryResource(const char* resname, SClass_ID type,
		unsigned char mode = IE_NORMAL) = 0;
};

#endif

==> gemrb-0.6.0.tar.gz: gemrb-0.6.0/gemrb/plugins/Core/ResourceMgr.h <==
/* GemRB - Infinity Engine Emulator
 * Copyright (C) 2003 The GemRB Project
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * $Id: ResourceMgr.h 6153 2009-05-28 18:29:45Z lynxlupodian $
 *
 */

#ifndef RESOURCEMGR_H
#define RESOURCEMGR_H

#include "Plugin.h"
#include "../../includes/SClassID.h"
#include "DataStream.h"
#include "../../includes/globals.h"

#ifdef WIN32

#ifdef GEM_BUILD_DLL
#define GEM_EXPORT __declspec(dllexport)
#else
#define GEM_EXPORT __declspec(dllimport)
#endif

#else
#define GEM_EXPORT
#endif

class GEM_EXPORT ResourceMgr : public Plugin {
public:
	ResourceMgr(void);
	virtual ~ResourceMgr(void);
	virtual bool LoadResFile(const char* resfile) = 0;
	virtual bool HasResource(const char* resname, SClass_ID type, bool silent=false) = 0;
	virtual DataStream* GetResource(const char* resname, SClass_ID type, bool silent=false) = 0;
	virtual void* GetFactoryResource(const char* resname, SClass_ID type,
		unsigned char mode = IE_NORMAL, bool silent=false) = 0;
};

#endif
